#include <iostream>

auto main() -> int {
    std::cout << "Hello hello, world!\n";
}
